@@ -17,7 +17,7 @@ class Quarto:
             view_config = self._config["views"][view]
 
             if view == "table":
-                active_view = Table(datasource = datasource, primitives=view_config["primitives"], slug=view_config["slug"], title=view_config["title"], primary=view_config["primary"], output_list=view_config["output_list"], options=view_config["options"])
+                active_view = Table(datasource = datasource, primitives=view_config["primitives"], slug=view_config["slug"], title=view_config["title"], primary=view_config["primary"], output_list=view_config["output_list"], output_map=view_config["output_map"], options=view_config["options"])
             elif view == "gallery":
                 active_view = Gallery(datasource = datasource, primitives=view_config["primitives"], slug=view_config["slug"], title=view_config["title"], primary=view_config["primary"], output_map=view_config["output_map"], options=view_config["options"])
             elif view == "map":
@@ -324,6 +324,13 @@ class Table(View):
            #    print("No description set")
            #    continue
 
+            print(item_data)
+            title_field = self.output_map(item_data, name="Title")
+            name_field = self.output_map(item_data, name="Subtitle")
+            desc_field = self.output_map(item_data, name="Description")
+            img_field = self.output_map(item_data, name="Image")
+            url_field = self.output_map(item_data, "URL")
+            author_field = self.output_map(item_data, "Author")
 
             filename = item_data["_filename_"]
 
@@ -357,7 +364,6 @@ class Table(View):
                 hugo_file.write("::: {.column-margin}\n")
                 hugo_file.write(f"<img src=\"{img_field}/full/400,/0/default.jpg\">\n\n")
                 hugo_file.write(f":::\n\n")
-              url_field = self.output_map(item_data, "URL")
               if url_field != None:
                 hugo_file.write(f"## Collection Website\n")
                 hugo_file.write(f"<a href=\"{url_field}\"/>{title_field}</a> ({author_field})\n")
